| Title: | Bivariate Distributions via Conditional Specification |
|---|---|
| Description: | Implementation of bivariate binomial, geometric, and Poisson distributions based on conditional specifications. The package also includes tools for data generation and goodness-of-fit testing for these three distribution families. For methodological details, see Ghosh, Marques, and Chakraborty (2025) <doi:10.1080/03610926.2024.2315294>, Ghosh, Marques, and Chakraborty (2023) <doi:10.1080/03610918.2021.2004419>, and Ghosh, Marques, and Chakraborty (2021) <doi:10.1080/02664763.2020.1793307>. |
| Authors: | Mina Norouzirad [aut, cre] (ORCID: <https://orcid.org/0000-0003-0311-6888>), Filipe J. Marques [aut] (ORCID: <https://orcid.org/0000-0001-6453-6558>), Indranil Ghosh [ctb] (ORCID: <https://orcid.org/0000-0001-7910-8919>), FCT, I.P. [fnd] (under the scope of the projects UIDB/00297/2020 and UIDP/00297/2020 (NOVAMath)) |
| Maintainer: | Mina Norouzirad <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.1 |
| Built: | 2026-05-26 05:57:22 UTC |
| Source: | https://github.com/mnrzrad/bcd |
This dataset records the number of aborted flights by 109 aircrafts during two consecutive periods. The counts are cross-tabulated by the number of aborted flights in each period.
abortflightsabortflights
A data frame with 109 rows and 2 variables:
Number of aborted flights in Period 1.
Number of aborted flights in Period 2.
Barbiero, A. (2019). A bivariate geometric distribution allowing for positive or negative correlation. Communications in Statistics - Theory and Methods, 48 (11), 2842–-2861. doi:10.1080/03610926.2018.1473428.
Ghosh, I., Marques, F., & Chakraborty, S. (2023) A bivariate geometric distribution via conditional specification: properties and applications, Communications in Statistics - Simulation and Computation, 52:12, 5925–5945, doi:10.1080/03610918.2021.2004419
data(abortflights) head(abortflights) table(abortflights$X, abortflights$Y)data(abortflights) head(abortflights) table(abortflights$X, abortflights$Y)
Computes the probability mass function (p.m.f.) of the bivariate binomial conditionals distribution (BBCD) as defined by Ghosh, Marques, and Chakraborty (2025). The distribution is characterized by conditional binomial distributions for and .
dbinomBCD(x, y, n1, n2, p1, p2, lambda)dbinomBCD(x, y, n1, n2, p1, p2, lambda)
x |
value of |
y |
value of |
n1 |
number of trials for |
n2 |
number of trials for |
p1 |
base success probability for |
p2 |
base success probability for |
lambda |
dependence parameter, must be positive. |
The joint p.m.f. of the BBCD is
where , , and is the normalizing constant.
The probability .
Ghosh, I., Marques, F., & Chakraborty, S. (2025). A form of bivariate binomial conditionals distributions. Communications in Statistics - Theory and Methods, 54(2), 534–553. doi:10.1080/03610926.2024.2315294
pbinomBCD rbinomBCD MLEbinomBCD
# Compute P(X = 2, Y = 1) with n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 0.5 dbinomBCD(x = 2, y = 1, n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 0.5) # Example with independence (lambda = 1) dbinomBCD(x = 2, y = 1, n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 1.0)# Compute P(X = 2, Y = 1) with n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 0.5 dbinomBCD(x = 2, y = 1, n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 0.5) # Example with independence (lambda = 1) dbinomBCD(x = 2, y = 1, n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 1.0)
Computes the joint probability mass function (p.m.f.) of a Bivariate Geometric Conditional Distributions (BGCD) based on Ghosh, Marques, and Chakraborty (2023). This distribution models paired count data with geometric conditionals, incorporating dependence between variables and .
dgeomBCD(x, y, q1, q2, q3)dgeomBCD(x, y, q1, q2, q3)
x |
value of |
y |
value of |
q1 |
probability parameter for |
q2 |
probability parameter for |
q3 |
dependence parameter, in |
The joint p.m.f. of the BGCD is:
where is the normalizing constant computed by the function normalize_constant_BGCD.
Note that:
- : indicates the negative correlation between and
- : indicates the independence between and
The probability for each pair of and .
Ghosh, I., Marques, F., & Chakraborty, S.(2023) A bivariate geometric distribution via conditional specification: properties and applications, Communications in Statistics - Simulation and Computation, 52:12, 5925–5945, doi:10.1080/03610918.2021.2004419
# Compute P(X = 1, Y = 2) with q1 = 0.5, q2 = 0.6, q3 = 0.8 dgeomBCD(x = 1, y = 2, q1 = 0.5, q2 = 0.6, q3 = 0.8) # # Compute P(X = 0, Y = 4) with q1 = 0.5, q2 = 0.6, q3 = 0.8 dgeomBCD(x = 0, y = 4, q1 = 0.5, q2 = 0.6, q3 = 0.8)# Compute P(X = 1, Y = 2) with q1 = 0.5, q2 = 0.6, q3 = 0.8 dgeomBCD(x = 1, y = 2, q1 = 0.5, q2 = 0.6, q3 = 0.8) # # Compute P(X = 0, Y = 4) with q1 = 0.5, q2 = 0.6, q3 = 0.8 dgeomBCD(x = 0, y = 4, q1 = 0.5, q2 = 0.6, q3 = 0.8)
Computes the joint probability mass function (p.m.f.) of a Bivariate Poisson Conditionals distribution (BPCD) based on Ghosh, Marques, and Chakraborty (2021).
dpoisBCD(x, y, lambda1, lambda2, lambda3)dpoisBCD(x, y, lambda1, lambda2, lambda3)
x |
value of |
y |
value of |
lambda1 |
rate parameter for |
lambda2 |
rate parameter for |
lambda3 |
dependence parameter that must be |
The joint p.m.f. of the BGCD is
where , and is the normalizing constant computed by the function normalize_constant_BPCD.
Key properties of the BPCD include:
- Negative correlation for ,
- Independence for .
probability for each pair of and .
Ghosh, I., Marques, F., & Chakraborty, S. (2021). A new bivariate Poisson distribution via conditional specification: properties and applications. Journal of Applied Statistics, 48(16), 3025-3047. doi:10.1080/02664763.2020.1793307
# Compute P(X = 1, Y = 2) with lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5 dpoisBCD(x = 1, y = 2, lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5) # Compute P(X = 0, Y = 1) with lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5 dpoisBCD(x = 0, y = 1, lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5)# Compute P(X = 1, Y = 2) with lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5 dpoisBCD(x = 1, y = 2, lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5) # Compute P(X = 0, Y = 1) with lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5 dpoisBCD(x = 0, y = 1, lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5)
A list of data frames for five consecutive seasons (2014/15 to 2018/19) from the English Premier League. Each data frame contains the number of full-time home ('X') and away ('Y') goals scored in each match of the season.
data(eplSeasonGoals)data(eplSeasonGoals)
A named list of 5 data frames:
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
380 rows, variables: X (home goals), Y (away goals)
Data source: English Premier League match results from https://football-data.co.uk/ (formerly hosted on datahub.io).
Ghosh, I., Marques, F., & Chakraborty, S. (2021). A new bivariate Poisson distribution via conditional specification: properties and applications. Journal of Applied Statistics, 48(16), 3025-3047. doi:10.1080/02664763.2020.1793307
data(eplSeasonGoals) head(eplSeasonGoals[["1415"]]) head(eplSeasonGoals[["2425"]])data(eplSeasonGoals) head(eplSeasonGoals[["1415"]]) head(eplSeasonGoals[["2425"]])
Performs a goodness-of-fit test using the Freeman–Tukey (F–T) statistic for a given dataset and a specified bivariate distribution via Conditional Specification.
FTtest(data, distribution, params, num_params)FTtest(data, distribution, params, num_params)
data |
a dataset or matrix with two columns. |
distribution |
a string specifying the theoretical distribution ('"BBCD"', '"BBPD"', or '"BBGD"'). |
params |
a named list of parameters required by the specified distribution. |
num_params |
an integer specifying the number of parameters that were estimated |
The Freeman–Tukey (F–T) statistic is used to assess the goodness of fit in contingency tables. It is defined as:
where and are the observed and expected frequencies, respectively.
The statistic asymptotically follows a chi-squared distribution with
degrees of freedom, where is the number of rows
and is the number of columns in the contingency table.
A list with components:
Observed frequency table
Expected frequency table under the specified distribution
Result of the Freeman–Tukey test, a list with test statistic and p-value
samples <- rgeomBCD(n = 20, q1 = 0.5, q2 = 0.5, q3 = 0.1, seed = 123) params <- MLEgeomBCD(samples) result_bgcd <- FTtest(samples, "BGCD", params, num_params = 3) result_bgcd samples <- rpoisBCD(20, lambda1=.5, lambda2=.5, lambda3=.5) params <- MLEpoisBCD(samples) result_bpcd <- FTtest(samples, "BPCD", params, num_params = 3) result_bpcdsamples <- rgeomBCD(n = 20, q1 = 0.5, q2 = 0.5, q3 = 0.1, seed = 123) params <- MLEgeomBCD(samples) result_bgcd <- FTtest(samples, "BGCD", params, num_params = 3) result_bgcd samples <- rpoisBCD(20, lambda1=.5, lambda2=.5, lambda3=.5) params <- MLEpoisBCD(samples) result_bpcd <- FTtest(samples, "BPCD", params, num_params = 3) result_bpcd
This dataset records counts of surface faults () and interior faults () observed in 100 optical lenses
lensfaultslensfaults
A data frame with 100 rows and 2 variables:
Number of surface faults in a lens.
Number of interior faults in the same lens.
Aitchison, J., & Ho, C. H. (1989). The multivariate Poisson-log normal distribution. Biometrika, 76(4), 643–653.
Ghosh, I., Marques, F., & Chakraborty, S. (2021). A new bivariate Poisson distribution via conditional specification: properties and applications. Journal of Applied Statistics, 48(16), 3025-3047. doi:10.1080/02664763.2020.1793307
Estimates the parameters of a Bivariate Binomial Conditionals via Conditional Specification using maximum likelihood.
MLEbinomBCD(data, fixed_n1 = NULL, fixed_n2 = NULL, verbose = TRUE)MLEbinomBCD(data, fixed_n1 = NULL, fixed_n2 = NULL, verbose = TRUE)
data |
A data frame or matrix with columns 'X' and 'Y' |
fixed_n1 |
known value of 'n1' (NULL to estimate) |
fixed_n2 |
known value of 'n2' (NULL to estimate) |
verbose |
logical; print progress |
A list of class "MLEpoisBCD" containing:
n1estimated n1
n2estimated n2
p1estimated p1
p2estimated p2
lambdaestimated lambda
logLikMaximum log-likelihood achieved.
AICAkaike Information Criterion.
BICBayesian Information Criterion.
convergenceConvergence status from the optimizer (0 means successful).
data <- rbinomBCD(n = 10,n1 = 5, n2 = 3, p1 = 0.6, p2 = 0.4, lambda = 1.2) MLEbinomBCD(data) MLEbinomBCD(data, fixed_n1 = 5, fixed_n2 = 3)data <- rbinomBCD(n = 10,n1 = 5, n2 = 3, p1 = 0.6, p2 = 0.4, lambda = 1.2) MLEbinomBCD(data) MLEbinomBCD(data, fixed_n1 = 5, fixed_n2 = 3)
Estimates the parameters of a bivariate geometric distribution via Conditional Specification using maximum likelihood.
MLEgeomBCD(data, initial_values = c(0.5, 0.5, 0.5))MLEgeomBCD(data, initial_values = c(0.5, 0.5, 0.5))
data |
data frame or matrix with two columns, representing paired observations of count variables |
initial_values |
numeric vector of length 3 with initial values for the parameters |
The model estimates parameters from a joint distribution for with the form:
where is the normalizing constant.
A list containing:
q1estimated q1.
q2estimated q2.
q3estimated q3.
logLikMaximum log-likelihood achieved.
AICAkaike Information Criterion.
BICBayesian Information Criterion.
convergenceConvergence status from the optimizer (0 means successful).
Ghosh, I., Marques, F., & Chakraborty, S. (2023) A bivariate geometric distribution via conditional specification: properties and applications, Communications in Statistics - Simulation and Computation, 52:12, 5925–5945, doi:10.1080/03610918.2021.2004419
# Simulate data samples <- rgeomBCD(n = 50, q1 = 0.2, q2 = 0.2, q3 = 0.5) result <-MLEgeomBCD(samples) print(result) # For better estimation accuracy and stability, consider increasing the sample size (n = 1000) data(abortflights) MLEgeomBCD(abortflights)# Simulate data samples <- rgeomBCD(n = 50, q1 = 0.2, q2 = 0.2, q3 = 0.5) result <-MLEgeomBCD(samples) print(result) # For better estimation accuracy and stability, consider increasing the sample size (n = 1000) data(abortflights) MLEgeomBCD(abortflights)
Estimates the parameters of a bivariate Poisson distribution via Conditional Specification using maximum likelihood.
MLEpoisBCD(data, initial_values = NULL)MLEpoisBCD(data, initial_values = NULL)
data |
data frame or matrix with two columns, representing paired observations of count variables |
initial_values |
optional named list with initial values for the parameters: |
The model estimates parameters from a joint distribution for with the form:
where , and is the normalizing constant.
A list of class "MLEpoisBCD" containing:
lambda1estimated lambda1.
lambda2estimated lambda2.
lambda3estimated dependence parameter (must be in (0, 1]).
logLikMaximum log-likelihood achieved.
AICAkaike Information Criterion.
BICBayesian Information Criterion.
convergenceConvergence status from the optimizer (0 means successful).
# Simulate data data <- rpoisBCD(n = 50, lambda1 = 3, lambda2 = 5, lambda3 = 1) result <- MLEpoisBCD(data) print(result) data(eplSeasonGoals) MLEpoisBCD(eplSeasonGoals[["1819"]]) data(lensfaults) MLEpoisBCD(lensfaults)# Simulate data data <- rpoisBCD(n = 50, lambda1 = 3, lambda2 = 5, lambda3 = 1) result <- MLEpoisBCD(data) print(result) data(eplSeasonGoals) MLEpoisBCD(eplSeasonGoals[["1819"]]) data(lensfaults) MLEpoisBCD(lensfaults)
Computes the cumulative distribution function (c.d.f.) of a bivariate binomial conditionals distribution (BBCD) as defined by Ghosh, Marques, and Chakraborty (2025).
pbinomBCD(x, y, n1, n2, p1, p2, lambda)pbinomBCD(x, y, n1, n2, p1, p2, lambda)
x |
value at which the c.d.f. is evaluated |
y |
value at which the c.d.f. is evaluated |
n1 |
number of trials for |
n2 |
number of trials for |
p1 |
base success probability for |
p2 |
base success probability for |
lambda |
dependence parameter, must be positive. |
The probability .
Ghosh, I., Marques, F., & Chakraborty, S. (2025). A form of bivariate binomial conditionals distributions. Communications in Statistics - Theory and Methodsm 54(2), 534–553. doi:10.1080/03610926.2024.2315294
# Compute P(X \le 2, Y \le 1) with n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 0.5 pbinomBCD(x = 2, y = 5, n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 0.5) # Example with independence (lambda = 1) pbinomBCD(x = 1, y = 1, n1 = 10, n2 = 10, p1 = 0.3, p2 = 0.6, lambda = 1)# Compute P(X \le 2, Y \le 1) with n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 0.5 pbinomBCD(x = 2, y = 5, n1 = 5, n2 = 5, p1 = 0.5, p2 = 0.4, lambda = 0.5) # Example with independence (lambda = 1) pbinomBCD(x = 1, y = 1, n1 = 10, n2 = 10, p1 = 0.3, p2 = 0.6, lambda = 1)
Computes the cumulative distribution function (c.d.f.) of a bivariate geometric conditionals distribution (BGCD) based on Ghosh, Marques, and Chakraborty (2023).
pgeomBCD(x, y, q1, q2, q3)pgeomBCD(x, y, q1, q2, q3)
x |
value at which the c.d.f. is evaluated |
y |
value at which the c.d.f. is evaluated |
q1 |
probability parameter for |
q2 |
probability parameter for |
q3 |
dependence parameter, in (0, 1] |
The probability .
Ghosh, I., Marques, F., & Chakraborty, S. (2023) A bivariate geometric distribution via conditional specification: properties and applications, Communications in Statistics - Simulation and Computation, 52:12, 5925–5945, doi:10.1080/03610918.2021.2004419
# Compute P(X \le 1, Y \le 2) with q1 = 0.5, q2 = 0.6, q3 = 0.8 pgeomBCD(x = 1, y = 2, q1 = 0.5, q2 = 0.6, q3 = 0.8) # Example with small values pgeomBCD(x = 0, y = 0, q1 = 0.4, q2 = 0.3, q3 = 0.9)# Compute P(X \le 1, Y \le 2) with q1 = 0.5, q2 = 0.6, q3 = 0.8 pgeomBCD(x = 1, y = 2, q1 = 0.5, q2 = 0.6, q3 = 0.8) # Example with small values pgeomBCD(x = 0, y = 0, q1 = 0.4, q2 = 0.3, q3 = 0.9)
Computes the cumulative distribution function (c.d.f.) of a bivariate Poisson distribution (BPD) with conditional specification, as described by Ghosh, Marques, and Chakraborty (2021).
ppoisBCD(x, y, lambda1, lambda2, lambda3)ppoisBCD(x, y, lambda1, lambda2, lambda3)
x |
value at which the c.d.f. is evaluated |
y |
value at which the c.d.f. is evaluated |
lambda1 |
rate parameter for |
lambda2 |
rate parameter for |
lambda3 |
dependence parameter that must be (0, 1] |
The probability .
Ghosh, I., Marques, F., & Chakraborty, S. (2021). A new bivariate Poisson distribution via conditional specification: properties and applications. Journal of Applied Statistics, 48(16), 3025-3047. doi:10.1080/02664763.2020.1793307
# Compute P(X \le 1, Y \le 1) with lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5 ppoisBCD(x = 1, y = 1, lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5) # Example with larger values ppoisBCD(x = 2, y = 2, lambda1 = 1.0, lambda2 = 1.0, lambda3 = 0.8)# Compute P(X \le 1, Y \le 1) with lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5 ppoisBCD(x = 1, y = 1, lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5) # Example with larger values ppoisBCD(x = 2, y = 2, lambda1 = 1.0, lambda2 = 1.0, lambda3 = 0.8)
Generates random samples from a bivariate binomial conditionals distribution (BBCD).
rbinomBCD(n, n1, n2, p1, p2, lambda, seed = 123, verbose = TRUE)rbinomBCD(n, n1, n2, p1, p2, lambda, seed = 123, verbose = TRUE)
n |
number of samples to generate. |
n1 |
number of trials for |
n2 |
number of trials for |
p1 |
base success probability for |
p2 |
base success probability for |
lambda |
dependence parameter, must be positive. |
seed |
seed for random number generation (default = 123). |
verbose |
logical; if TRUE (default), prints progress updates and a summary. |
A data frame with columns 'X' and 'Y', containing the sampled values.
samples <- rbinomBCD(n = 100, n1 = 10, n2 = 10, p1 = 0.5, p2 = 0.4, lambda = 1.2) head(samples)samples <- rbinomBCD(n = 100, n1 = 10, n2 = 10, p1 = 0.5, p2 = 0.4, lambda = 1.2) head(samples)
Generates random samples from a bivariate geometric distribution (BGCD)
rgeomBCD(n, q1, q2, q3, seed = 123)rgeomBCD(n, q1, q2, q3, seed = 123)
n |
number of samples to generate |
q1 |
probability parameter for |
q2 |
probability parameter for |
q3 |
dependence parameter, in |
seed |
seed for random number generation (default = 123) |
A data frame with two columns: 'X' and 'Y', containing the sampled values.
# Generate 100 samples samples <- rgeomBCD(n = 100, q1 = 0.5, q2 = 0.5, q3 = 0.00001) head(samples) cor(samples$X, samples$Y) # Should be negative# Generate 100 samples samples <- rgeomBCD(n = 100, q1 = 0.5, q2 = 0.5, q3 = 0.00001) head(samples) cor(samples$X, samples$Y) # Should be negative
Generates random samples from a bivariate Poisson distribution (BPD).
rpoisBCD(n, lambda1, lambda2, lambda3, seed = 123)rpoisBCD(n, lambda1, lambda2, lambda3, seed = 123)
n |
number of samples to generate |
lambda1 |
rate parameter for |
lambda2 |
rate parameter for |
lambda3 |
dependence parameter that must be (0, 1] |
seed |
seed for random number generation (default = 123) |
A data frame with columns 'X' and 'Y', containing the sampled values.
samples <- rpoisBCD(n = 100, lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5) cor(samples$X, samples$Y) # Should be negativesamples <- rpoisBCD(n = 100, lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5) cor(samples$X, samples$Y) # Should be negative
This dataset records the number of seeds sown and the number of resulting plants grown over plots of fixed area (5 square feet).
seedplantseedplant
A data frame with n rows and 2 variables:
Number of seeds sown.
Number of plants grown.
Lakshminarayana, J., S. N. N. Pandit, and K. Srinivasa Rao. 1999. On a bivariate poisson distribution. Communications in Statistics - Theory and Methods, 28 (2), 267–276. doi:10.1080/03610929908832297
Ghosh, I., Marques, F., & Chakraborty, S. (2025). A form of bivariate binomial conditionals distributions. Communications in Statistics - Theory and Methods, 54(2), 534–553. doi:10.1080/03610926.2024.2315294
data(seedplant) head(seedplant) plot(seedplant$X, seedplant$Y, xlab = "Seeds Sown", ylab = "Plants Grown", main = "Seed vs. Plant Count per Plot")data(seedplant) head(seedplant) plot(seedplant$X, seedplant$Y, xlab = "Seeds Sown", ylab = "Plants Grown", main = "Seed vs. Plant Count per Plot")
Accident records for 122 experienced railway shunters across two historical periods.
shaccshacc
A data frame with 122 rows and 2 variables:
Number of accidents during the 6-year period from 1937 to 1942.
Number of accidents during the 5-year period from 1943 to 1947.
This dataset is useful for analyzing accident rates before and after possible policy or operational changes.
Arbous, A. G., & Kerrich, J. E. (1951). Accident statistics and the concept of accident-proneness. Biometrics, 7(4), 340. doi:10.2307/3001656
Ghosh, I., Marques, F., & Chakraborty, S. (2025). A form of bivariate binomial conditionals distributions. Communications in Statistics - Theory and Methods, 54(2), 534–553. doi:10.1080/03610926.2024.2315294
data(shacc) head(shacc) plot(shacc$X, shacc$Y, xlab = "Accidents 1937–42", ylab = "Accidents 1943–47")data(shacc) head(shacc) plot(shacc$X, shacc$Y, xlab = "Accidents 1937–42", ylab = "Accidents 1943–47")